@@ -27,6 +27,7 @@
 #include <popt.h>
 #include <gdk/gdkwindow.h>
 #include <libbonobo.h>
+#include <login-helper/login-helper.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <X11/Xatom.h>
@@ -39,6 +40,17 @@
 #include "zoom-region-private.h"
 #include "GNOME_Magnifier.h"
 
+typedef struct
+{
+    LoginHelper parent;
+    Magnifier *mag;
+} MagLoginHelper;
+
+typedef struct 
+{
+    LoginHelperClass parent_class;
+} MagLoginHelperClass;
+
 static GObjectClass *parent_class = NULL;
 
 enum {
@@ -83,6 +95,65 @@ static gboolean magnifier_check_set_struts (Magnifier *magnifier);
 static gboolean magnifier_reset_struts_at_idle (gpointer data);
 static gboolean _is_override_redirect = FALSE;
 
+static Window*
+mag_login_helper_get_raise_windows (LoginHelper *helper)
+{
+    Window *mainwin = NULL;
+    MagLoginHelper *mag_helper = (MagLoginHelper *) helper;
+    Magnifier *magnifier = MAGNIFIER (mag_helper->mag);
+
+    if (magnifier && magnifier->priv && magnifier->priv->w)
+    {
+	mainwin = g_new0 (Window, 2);
+	mainwin[0] = GDK_WINDOW_XWINDOW (magnifier->priv->w->window);
+	mainwin[1] = None;
+    }
+    return mainwin;
+}
+
+static LoginHelperDeviceReqFlags
+mag_login_helper_get_device_reqs (LoginHelper *helper)
+{
+    /* means "don't grab the xserver or core pointer", 
+       and "we need to raise windows" */
+
+    return LOGIN_HELPER_GUI_EVENTS | 
+	LOGIN_HELPER_POST_WINDOWS | 
+	LOGIN_HELPER_CORE_POINTER;
+}
+
+static gboolean
+mag_login_helper_set_safe (LoginHelper *helper, gboolean ignored)
+{
+    return TRUE;
+}
+
+static void
+mag_login_helper_class_init (MagLoginHelperClass *klass)
+{
+	LoginHelperClass *login_helper_class = LOGIN_HELPER_CLASS(klass);
+	login_helper_class->get_raise_windows = mag_login_helper_get_raise_windows;
+	login_helper_class->get_device_reqs = mag_login_helper_get_device_reqs;
+	login_helper_class->set_safe = mag_login_helper_set_safe;
+}
+
+static void
+mag_login_helper_init (MagLoginHelper *helper)
+{
+    helper->mag = NULL; /* we set this with mag_login_helper_set_magnifier */
+}
+
+static void
+mag_login_helper_set_magnifier (MagLoginHelper *helper, Magnifier *mag)
+{
+    if (helper) 
+	helper->mag = mag;
+}
+
+BONOBO_TYPE_FUNC (MagLoginHelper, 
+		  LOGIN_HELPER_TYPE,
+		  mag_login_helper)
+
 gboolean
 magnifier_error_check (void)
 {
@@ -1526,6 +1597,7 @@ Magnifier *
 magnifier_new (gboolean override_redirect)
 {
 	Magnifier *mag;
+	MagLoginHelper *helper;
 	int ret;
 
 	_is_override_redirect = override_redirect;
@@ -1533,6 +1605,12 @@ magnifier_new (gboolean override_redirect)
 	mag = g_object_new (magnifier_get_type(), NULL);
 
 	_this_magnifier = mag; /* FIXME what about multiple instances? */
+
+	helper = g_object_new (mag_login_helper_get_type (), NULL);
+	mag_login_helper_set_magnifier (helper, mag);
+
+	bonobo_object_add_interface (bonobo_object (mag), 
+				     BONOBO_OBJECT (helper));
 	
 	ret = bonobo_activation_active_server_register (
 		MAGNIFIER_OAFIID, BONOBO_OBJREF (mag));
@@ -1550,3 +1628,4 @@ BONOBO_TYPE_FUNC_FULL (Magnifier,
 		       GNOME_Magnifier_Magnifier,
 		       BONOBO_TYPE_OBJECT,
 		       magnifier)
+
