@@ -128,6 +128,9 @@ int main(int argc, char ** argv){
 	GNOME_Magnifier_ZoomRegion zoom_region;
 	Bonobo_PropertyBag properties;
 	CORBA_Environment ev;
+	CORBA_any *rect_any;
+	GNOME_Magnifier_RectBounds *rectangle;
+
 	CORBA_exception_init (&ev);
 	
 	if (!bonobo_init (&argc, argv))
@@ -191,6 +194,19 @@ int main(int argc, char ** argv){
 		bonobo_pbclient_set_ulong (properties, "cursor-color", 0xFFF, NULL);
 		bonobo_object_release_unref (properties, NULL);
 		break;
+        case 'T':
+		rect_any = CORBA_any__alloc ();
+		rectangle = GNOME_Magnifier_RectBounds__alloc ();
+		rectangle->x1 = 800;
+		rectangle->x2 = 1024;
+		rectangle->y1 = 0;
+		rectangle->y2 = 800;
+		rect_any->_type = TC_GNOME_Magnifier_RectBounds;
+		rect_any->_value = ORBit_copy_value (rectangle, TC_GNOME_Magnifier_RectBounds);
+		properties = GNOME_Magnifier_Magnifier_getProperties (magnifier, &ev);
+		Bonobo_PropertyBag_setValue (properties, "target-display-bounds", rect_any, NULL);
+		bonobo_object_release_unref (properties, NULL);
+		break;
         }
 
 return 0;
